@@ -1,4 +1,3 @@
-/* vim: set sw=8: */
 /**
  * ms-excel-util.c: Utility functions for MS Excel import / export
  *
@@ -13,7 +12,7 @@
 #include <glib.h>
 
 #include "boot.h"
-#include "style.h"
+#include <style.h>
 #include "ms-excel-util.h"
 #include <goffice/goffice.h>
 #include <glib/gi18n-lib.h>
