@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fn-hebrew-date.c:  Built in hebrew date functions.
  *
@@ -365,47 +364,47 @@ gnumeric_date2julian (GnmFuncEvalInfo * ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const hebrew_datetime_functions[] = {
 	{"hdate", "|fff", help_hdate,
-	 gnumeric_hdate, NULL, NULL, NULL,
+	 gnumeric_hdate, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	{"hdate_heb", "|fff", help_hdate_heb,
-	 gnumeric_hdate_heb, NULL, NULL, NULL,
+	 gnumeric_hdate_heb, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"hdate_day", "|fff", help_hdate_day,
-	 gnumeric_hdate_day, NULL, NULL, NULL,
+	 gnumeric_hdate_day, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_UNITLESS,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"hdate_month", "|fff", help_hdate_month,
-	 gnumeric_hdate_month, NULL, NULL, NULL,
+	 gnumeric_hdate_month, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_UNITLESS,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"hdate_year", "|fff", help_hdate_year,
-	 gnumeric_hdate_year, NULL, NULL, NULL,
+	 gnumeric_hdate_year, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_UNITLESS,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"hdate_julian", "|fff", help_hdate_julian,
-	 gnumeric_hdate_julian, NULL, NULL, NULL,
+	 gnumeric_hdate_julian, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_UNITLESS,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"date2hdate", "|f", help_date2hdate,
-	 gnumeric_date2hdate, NULL, NULL, NULL,
+	 gnumeric_date2hdate, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"date2hdate_heb", "|f", help_date2hdate_heb,
-	 gnumeric_date2hdate_heb, NULL, NULL, NULL,
+	 gnumeric_date2hdate_heb, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	 {"date2julian", "|f", help_date2julian,
-	 gnumeric_date2julian, NULL, NULL, NULL,
+	 gnumeric_date2julian, NULL,
 	 GNM_FUNC_SIMPLE + GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_UNITLESS,
 	 GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	 GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
