@@ -15,14 +15,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef GNUMERIC_PLUGIN_ROFF_H
 #define GNUMERIC_PLUGIN_ROFF_H
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 
 void roff_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 		     WorkbookView const *wb_view, GsfOutput *output);
