@@ -1,7 +1,7 @@
 #ifndef PLUGIN_PSICONV_PLUGIN_H
 #define PLUGIN_PSICONV_PLUGIN_H
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <goffice/goffice.h>
 #include <gsf/gsf-input.h>
 
