@@ -31,11 +31,6 @@
 
 static PyObject *GnmModule = NULL;
 
-static PyTypeObject py_Boolean_object_type;
-typedef struct _py_Boolean_object py_Boolean_object;
-static PyObject *py_new_Boolean_object (gboolean value);
-static gboolean py_Boolean_as_gboolean (py_Boolean_object *self);
-
 static PyTypeObject py_CellRef_object_type;
 typedef struct _py_CellRef_object py_CellRef_object;
 
@@ -78,12 +73,25 @@ Module Gnumeric:
 
 */
 
+
+// Like PyDict_SetItemString, but takes ownership of val
+static void
+gnm_py_dict_store (PyObject *dict, const char *key, PyObject *val)
+{
+	PyDict_SetItemString (dict, key, val);
+	Py_DECREF (val);
+}
+
+
+
+
+
 #define GNUMERIC_MODULE \
-	(PyImport_AddModule ((char *) "Gnumeric"))
+	(PyImport_AddModule ("Gnumeric"))
 #define GNUMERIC_MODULE_GET(key) \
-	PyDict_GetItemString (PyModule_GetDict (GNUMERIC_MODULE), (char *) (key))
+	PyDict_GetItemString (PyModule_GetDict (GNUMERIC_MODULE), (key))
 #define GNUMERIC_MODULE_SET(key, val) \
-	PyDict_SetItemString (PyModule_GetDict (GNUMERIC_MODULE), (char *) (key), val)
+	gnm_py_dict_store (PyModule_GetDict (GNUMERIC_MODULE), (key), val)
 #define SET_EVAL_POS(val) \
 	GNUMERIC_MODULE_SET ("Gnumeric_eval_pos", PyCapsule_New (val, "eval_pos", NULL))
 #define UNSET_EVAL_POS \
@@ -104,10 +112,10 @@ py_obj_to_gnm_value (const GnmEvalPos *eval_pos, PyObject *py_val)
 		ret_val = value_new_empty ();
 	} else if (py_val == Py_None) {
 		ret_val = value_new_empty ();
-	} else if (py_val_type == (PyObject *) &py_Boolean_object_type) {
-		ret_val = value_new_bool (py_Boolean_as_gboolean ((py_Boolean_object *) py_val));
+	} else if (PyBool_Check (py_val)) {
+		ret_val = value_new_bool (py_val == Py_True);
 	} else if (PyLong_Check (py_val)) {
-		ret_val = value_new_int ((gint) PyLong_AsLong (py_val));
+		ret_val = value_new_float ((gnm_float)PyLong_AsLong (py_val));
 	} else if (PyFloat_Check (py_val)) {
 		ret_val = value_new_float ((gnm_float) PyFloat_AsDouble (py_val));
 	} else if (PyUnicode_Check (py_val)) {
@@ -224,9 +232,10 @@ gnm_value_to_py_obj (const GnmEvalPos *eval_pos, const GnmValue *val)
 	g_return_val_if_fail (eval_pos != NULL, NULL);
 	g_return_val_if_fail (val != NULL, NULL);
 
-    switch (val->v_any.type) {
+	switch (val->v_any.type) {
 	case VALUE_BOOLEAN:
-		py_val = py_new_Boolean_object (value_get_as_checked_bool (val));
+		py_val = value_get_as_checked_bool (val) ? Py_True : Py_False;
+		Py_INCREF (py_val);
 		break;
 	case VALUE_FLOAT:
 		py_val = PyFloat_FromDouble (value_get_as_float (val));
@@ -360,55 +369,6 @@ call_python_function (PyObject *python_fn, GnmEvalPos const *eval_pos, gint n_ar
 }
 
 
-/*
- * Boolean
- */
-
-struct _py_Boolean_object {
-	PyObject_HEAD
-	gboolean value;
-};
-
-static gboolean
-py_Boolean_as_gboolean (py_Boolean_object *self)
-{
-	return self->value;
-}
-
-static PyObject *
-py_Boolean_object_str (py_Boolean_object *self)
-{
-	return PyUnicode_FromString (self->value ? "True" : "False");
-}
-
-static void
-py_Boolean_object_dealloc (py_Boolean_object *self)
-{
-	PyObject_Del (self);
-}
-
-static PyObject *
-py_new_Boolean_object (gboolean value)
-{
-	py_Boolean_object *self;
-
-	self = PyObject_NEW (py_Boolean_object, &py_Boolean_object_type);
-	if (self == NULL) {
-		return NULL;
-	}
-	self->value = value;
-
-	return (PyObject *) self;
-}
-
-static PyTypeObject py_Boolean_object_type = {
-	PyVarObject_HEAD_INIT(NULL, 0)
-	.tp_name = (char *) "Boolean",
-	.tp_basicsize = sizeof (py_Boolean_object),
-	.tp_dealloc = (destructor) &py_Boolean_object_dealloc,
-	.tp_str = (reprfunc) py_Boolean_object_str
-};
-
 /*
  * CellRef
  */
@@ -442,9 +402,9 @@ py_CellRef_object_getattr (py_CellRef_object *self, gchar *name)
 	PyObject *result;
 
 	if (strcmp (name, "col") == 0) {
-		result = Py_BuildValue ((char *) "i", self->cell_ref.col);
+		result = PyLong_FromLong (self->cell_ref.col);
 	} else if (strcmp (name, "row") == 0) {
-		result = Py_BuildValue ((char *) "i", self->cell_ref.row);
+		result = PyLong_FromLong (self->cell_ref.row);
 	} else if (strcmp (name, "sheet") == 0) {
 		if (self->cell_ref.sheet)
 			result = pygobject_new (G_OBJECT (self->cell_ref.sheet));
@@ -453,11 +413,9 @@ py_CellRef_object_getattr (py_CellRef_object *self, gchar *name)
 			result = Py_None;
 		}
 	} else if (strcmp (name, "col_relative") == 0) {
-		result = Py_BuildValue ((char *) "i",
-				      self->cell_ref.col_relative ? 1 : 0);
+		result = PyBool_FromLong (self->cell_ref.col_relative);
 	} else if (strcmp (name, "row_relative") == 0) {
-		result = Py_BuildValue ((char *) "i",
-				      self->cell_ref.row_relative ? 1 : 0);
+		result = PyBool_FromLong (self->cell_ref.row_relative);
 	} else {
 		result = PyObject_CallMethod ((PyObject *) self, name, NULL);
 	}
@@ -487,7 +445,7 @@ py_new_CellRef_object (GnmCellRef const *cell_ref)
 
 static PyTypeObject py_CellRef_object_type = {
 	PyVarObject_HEAD_INIT(NULL, 0)
-	.tp_name = (char *) "CellRef",
+	.tp_name = "CellRef",
 	.tp_basicsize = sizeof (py_CellRef_object),
 	.tp_dealloc = (destructor) &py_CellRef_object_dealloc,
 	.tp_getattr = (getattrfunc) &py_CellRef_object_getattr,
@@ -512,8 +470,7 @@ static PyObject *
 py_RangeRef_get_tuple_method (py_RangeRef_object *self, PyObject *args);
 
 static struct PyMethodDef py_RangeRef_object_methods[] = {
-	{(char *) "get_tuple", (PyCFunction) py_RangeRef_get_tuple_method,
-	 METH_VARARGS},
+	{"get_tuple", (PyCFunction) py_RangeRef_get_tuple_method, METH_VARARGS},
 	{NULL, NULL}
 };
 
@@ -526,11 +483,11 @@ py_RangeRef_as_RangeRef (py_RangeRef_object *self)
 static PyObject *
 py_RangeRef_get_tuple_method (py_RangeRef_object *self, PyObject *args)
 {
-	if (!PyArg_ParseTuple (args, (char *) ":get_tuple")) {
+	if (!PyArg_ParseTuple (args, ":get_tuple")) {
 		return NULL;
 	}
 
-	return Py_BuildValue ((char *) "(O&O&)",
+	return Py_BuildValue ("(O&O&)",
 			      py_new_CellRef_object, &self->range_ref.a,
 			      py_new_CellRef_object, &self->range_ref.b);
 }
@@ -569,7 +526,7 @@ py_new_RangeRef_object (const GnmRangeRef *range_ref)
 
 static PyTypeObject py_RangeRef_object_type = {
 	PyVarObject_HEAD_INIT(NULL, 0)
-	.tp_name = (char *) "RangeRef",
+	.tp_name = "RangeRef",
 	.tp_basicsize = sizeof (py_RangeRef_object),
 	.tp_dealloc = (destructor) &py_RangeRef_object_dealloc,
 	.tp_getattr = (getattrfunc) &py_RangeRef_object_getattr,
@@ -639,7 +596,7 @@ py_new_GnumericFunc_object (GnmFunc *fn_def, const GnmEvalPos *opt_eval_pos)
 
 static PyTypeObject py_GnumericFunc_object_type = {
 	PyVarObject_HEAD_INIT(NULL,0)
-	.tp_name = (char *) "GnumericFunc",
+	.tp_name = "GnumericFunc",
 	.tp_basicsize = sizeof (py_GnumericFunc_object),
 	.tp_dealloc = (destructor) &py_GnumericFunc_object_dealloc,
 	.tp_call = (ternaryfunc) py_GnumericFunc_call
@@ -651,7 +608,7 @@ static PyTypeObject py_GnumericFunc_object_type = {
 
 struct _py_GnumericFuncDict_object {
 	PyObject_HEAD
-	PyObject *module_dict;
+	// PyObject *module_dict;
 };
 
 
@@ -661,7 +618,7 @@ py_GnumericFuncDict_subscript (py_GnumericFuncDict_object *self, PyObject *key)
 	gchar *fn_name;
 	GnmFunc *fn_def;
 
-	if (!PyArg_Parse(key, (char *) "s", &fn_name)) {
+	if (!PyArg_Parse(key, "s", &fn_name)) {
 		return NULL;
 	}
 
@@ -684,27 +641,18 @@ py_GnumericFuncDict_object_dealloc (py_GnumericFuncDict_object *self)
 static PyObject *
 py_new_GnumericFuncDict_object (PyObject *module_dict)
 {
-	py_GnumericFuncDict_object *self;
-
-	self = PyObject_NEW (py_GnumericFuncDict_object, &py_GnumericFuncDict_object_type);
-	if (self == NULL) {
-		return NULL;
-	}
-
-	self->module_dict = module_dict;
-
-	return (PyObject *) self;
+	return (PyObject*) PyObject_NEW (py_GnumericFuncDict_object, &py_GnumericFuncDict_object_type);
 }
 
 PyMappingMethods py_GnumericFuncDict_mapping_methods = {
-	0, /* mp_length */
-	(binaryfunc) py_GnumericFuncDict_subscript, /* mp_subscript */
-	0  /* mp_ass_subscript */
+	.mp_length = NULL,
+	.mp_subscript = (binaryfunc) py_GnumericFuncDict_subscript,
+	.mp_ass_subscript = NULL
 };
 
 static PyTypeObject py_GnumericFuncDict_object_type = {
 	PyVarObject_HEAD_INIT(NULL, 0)
-	.tp_name = (char *) "GnumericFuncDict",
+	.tp_name = "GnumericFuncDict",
 	.tp_basicsize = sizeof (py_GnumericFuncDict_object),
 	.tp_dealloc = (destructor) &py_GnumericFuncDict_object_dealloc,
 	.tp_as_mapping = &py_GnumericFuncDict_mapping_methods
@@ -729,13 +677,13 @@ static PyObject *
 py_GnmPlugin_get_description_method (py_GnmPlugin_object *self, PyObject *args);
 
 static struct PyMethodDef py_GnmPlugin_object_methods[] = {
-	{(char *) "get_dir_name",
+	{"get_dir_name",
 	 (PyCFunction) py_GnmPlugin_get_dir_name_method,    METH_VARARGS},
-	{(char *) "get_id",
+	{"get_id",
 	 (PyCFunction) py_GnmPlugin_get_id_method,          METH_VARARGS},
-	{(char *) "get_name",
+	{"get_name",
 	 (PyCFunction) py_GnmPlugin_get_name_method,        METH_VARARGS},
-	{(char *) "get_description",
+	{"get_description",
 	 (PyCFunction) py_GnmPlugin_get_description_method, METH_VARARGS},
 	{NULL, NULL}
 };
@@ -743,7 +691,7 @@ static struct PyMethodDef py_GnmPlugin_object_methods[] = {
 static PyObject *
 py_GnmPlugin_get_dir_name_method (py_GnmPlugin_object *self, PyObject *args)
 {
-	if (!PyArg_ParseTuple (args, (char *) ":get_dir_name")) {
+	if (!PyArg_ParseTuple (args, ":get_dir_name")) {
 		return NULL;
 	}
 
@@ -753,7 +701,7 @@ py_GnmPlugin_get_dir_name_method (py_GnmPlugin_object *self, PyObject *args)
 static PyObject *
 py_GnmPlugin_get_id_method (py_GnmPlugin_object *self, PyObject *args)
 {
-	if (!PyArg_ParseTuple (args, (char *) ":get_id")) {
+	if (!PyArg_ParseTuple (args, ":get_id")) {
 		return NULL;
 	}
 
@@ -763,7 +711,7 @@ py_GnmPlugin_get_id_method (py_GnmPlugin_object *self, PyObject *args)
 static PyObject *
 py_GnmPlugin_get_name_method (py_GnmPlugin_object *self, PyObject *args)
 {
-	if (!PyArg_ParseTuple (args, (char *) ":get_name")) {
+	if (!PyArg_ParseTuple (args, ":get_name")) {
 		return NULL;
 	}
 
@@ -773,7 +721,7 @@ py_GnmPlugin_get_name_method (py_GnmPlugin_object *self, PyObject *args)
 static PyObject *
 py_GnmPlugin_get_description_method (py_GnmPlugin_object *self, PyObject *args)
 {
-	if (!PyArg_ParseTuple (args, (char *) ":get_description")) {
+	if (!PyArg_ParseTuple (args, ":get_description")) {
 		return NULL;
 	}
 
@@ -820,7 +768,7 @@ py_new_GnmPlugin_object (GOPlugin *pinfo)
 
 static PyTypeObject py_GnmPlugin_object_type = {
 	PyVarObject_HEAD_INIT(&PyType_Type, 0)
-	.tp_name = (char *) "GOPlugin",
+	.tp_name = "GOPlugin",
 	.tp_basicsize = sizeof (py_GnmPlugin_object),
 	.tp_dealloc = (destructor) &py_GnmPlugin_object_dealloc,
 	.tp_getattr = (getattrfunc) &py_GnmPlugin_object_getattr,
@@ -832,8 +780,8 @@ init_err (PyObject *module_dict, const char *name, GnmStdError e)
 {
 	GnmValue *v = value_new_error_std (NULL, e);
 
-	PyDict_SetItemString
-		(module_dict, (char *)name,
+	gnm_py_dict_store
+		(module_dict, name,
 		 PyUnicode_FromString (v->v_err.mesg->str));
 
 	value_release (v);
@@ -841,20 +789,13 @@ init_err (PyObject *module_dict, const char *name, GnmStdError e)
 
 
 PyObject *
-py_initgnumeric ()
+py_initgnumeric (void)
 {
 	PyObject *module_dict;
 
 	static struct PyModuleDef GnmModuleDef = {
 		PyModuleDef_HEAD_INIT,	/* m_base */
-		(char *) "Gnumeric",	/* m_name */
-		0,	/* m_doc */
-		0,	/* m_ size */
-		0,	/* m_methods */
-		0,	/* m_reload */
-		0,	/* m_traverse */
-		0,	/* m_clear */
-		0,	/* m_free */
+		.m_name = "Gnumeric",
 	};
 
 	if (GnmModule)
@@ -862,14 +803,13 @@ py_initgnumeric ()
 	GnmModule = PyModule_Create (&GnmModuleDef);
 	module_dict = PyModule_GetDict (GnmModule);
 
-	(void) PyDict_SetItemString
-		(module_dict, (char *) "TRUE", py_new_Boolean_object (TRUE));
-	(void) PyDict_SetItemString
-		(module_dict, (char *) "FALSE", py_new_Boolean_object (FALSE));
+	// For historical reasons.  New code use python True/False.
+	gnm_py_dict_store (module_dict, "TRUE", PyBool_FromLong (TRUE));
+	gnm_py_dict_store (module_dict, "FALSE", PyBool_FromLong (FALSE));
 
-	(void) PyDict_SetItemString
-		(module_dict, (char *) "GnumericError",
-		 PyErr_NewException ((char *) "Gnumeric.GnumericError",
+	gnm_py_dict_store
+		(module_dict, "GnumericError",
+		 PyErr_NewException ("Gnumeric.GnumericError",
 				     NULL, NULL));
 
 	init_err (module_dict, "GnumericErrorNULL", GNM_ERROR_NULL);
@@ -880,13 +820,23 @@ py_initgnumeric ()
 	init_err (module_dict, "GnumericErrorNUM", GNM_ERROR_NUM);
 	init_err (module_dict, "GnumericErrorNA", GNM_ERROR_NA);
 
-	(void) PyDict_SetItemString
-		(module_dict, (char *) "functions",
+	gnm_py_dict_store
+		(module_dict, "functions",
 		 py_new_GnumericFuncDict_object (module_dict));
 
 	return GnmModule;
 }
 
+void
+py_gnumeric_shutdown (void)
+{
+	if (GnmModule) {
+		// At least clear the module.  We leak a ref somewhere.
+		PyDict_Clear (PyModule_GetDict (GnmModule));
+		Py_CLEAR (GnmModule);
+	}
+}
+
 void
 py_gnumeric_add_plugin (PyObject *module, GnmPyInterpreter *interpreter)
 {
@@ -905,7 +855,7 @@ py_gnumeric_add_plugin (PyObject *module, GnmPyInterpreter *interpreter)
 			name[i] = '_';
 	key = g_strconcat ("plugin_", name, "_info", NULL);
  	py_pinfo = py_new_GnmPlugin_object (pinfo);
-	(void) PyDict_SetItemString (module_dict, key, py_pinfo);
+	gnm_py_dict_store (module_dict, key, py_pinfo);
 	g_free (name);
 	g_free (key);
 }
