@@ -308,7 +308,7 @@ dialog_doc_metadata_transform_str_to_timestamp (const char *str,
 		int_serial = (int)serial;
 		s = go_date_serial_to_timet (int_serial, NULL);
 
-		if (gnm_abs (serial - int_serial) >= 1.0 || s == (time_t)-1) {
+		if (gnm_abs (serial - int_serial) >= 1 || s == (time_t)-1) {
 			s = time (NULL);
 		} else
 			s += (gnm_fake_round (3600 * 24 * (serial - int_serial)));
@@ -1967,8 +1967,8 @@ cb_dialog_doc_metadata_recalc_max_changed (GtkEntry          *entry,
 
 static gboolean
 cb_dialog_doc_metadata_recalc_tolerance_changed (GtkEntry          *entry,
-					   G_GNUC_UNUSED GdkEventFocus *event,
-					   DialogDocMetaData *state)
+						 G_GNUC_UNUSED GdkEventFocus *event,
+						 DialogDocMetaData *state)
 {
 	gnm_float val;
 	if (!entry_to_float (entry, &val, TRUE))
@@ -2014,7 +2014,7 @@ dialog_doc_metadata_init_calculations_page (DialogDocMetaData *state)
 	buf = g_strdup_printf ("%d", state->wb->iteration.max_number);
 	gtk_entry_set_text (state->recalc_max, buf);
 	g_free (buf);
-	buf = g_strdup_printf ("%g", state->wb->iteration.tolerance);
+	buf = g_strdup_printf ("%" GNM_FORMAT_g, state->wb->iteration.tolerance);
 	gtk_entry_set_text (state->recalc_tolerance, buf);
 	g_free (buf);
 
