@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-paste-special.c: The dialog for selecting non-standard
  *    behaviors when pasting.
@@ -22,8 +21,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <wbc-gtk.h>
 #include <gui-util.h>
@@ -31,7 +30,6 @@
 #include <selection.h>
 #include <cmd-edit.h>
 
-#include <gtk/gtk.h>
 
 static char const * const paste_type_group[] = {
 	"paste-type-all",
@@ -246,7 +244,7 @@ dialog_paste_special (WBCGtk *wbcg)
 
 	if (gnm_dialog_raise_if_exists (wbcg, GNM_PASTE_SPECIAL_KEY))
 		return;
-	gui = gnm_gtk_builder_load ("paste-special.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/paste-special.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
