@@ -372,7 +372,7 @@ gnm_expr_is_array (GnmExpr const *expr)
  * Returns: (transfer full): An array corner expression
  **/
 static GnmExpr const *
-gnm_expr_new_array_corner(int cols, int rows, GnmExpr const *expr)
+gnm_expr_new_array_corner (int cols, int rows, GnmExpr const *expr)
 {
 	GnmExprArrayCorner *ans;
 
@@ -937,7 +937,7 @@ bin_arith (GnmExpr const *expr, GnmEvalPos const *ep,
 		break;
 
 	case GNM_EXPR_OP_DIV:
-		if (vb == 0.0)
+		if (vb == 0)
 			return value_new_error_DIV0 (ep);
 		res = va / vb;
 		break;
