@@ -1,8 +1,6 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_GRAPH_WINDOW_H_
 # define _GNM_GRAPH_WINDOW_H_
 
-#include <gtk/gtk.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
