@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-data-slicer-field.h : The definition of a content for a data slicer
  *
@@ -21,10 +20,10 @@
  */
 
 #include <gnumeric-config.h>
-#include "go-data-slicer-field-impl.h"
-#include "go-data-slicer-impl.h"
-#include "go-data-cache-field.h"
-#include "go-data-cache.h"
+#include <go-data-slicer-field-impl.h>
+#include <go-data-slicer-impl.h>
+#include <go-data-cache-field.h>
+#include <go-data-cache.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
