@@ -28,6 +28,9 @@ G_BEGIN_DECLS
 /* ------------------------------------------------------------------------- */
 
 gnm_float log1pmx (gnm_float x);
+gnm_float lgamma1p (gnm_float a);
+gnm_float bd0(gnm_float x, gnm_float M);
+gnm_float gnm_taylor_log1p (gnm_float x, int k);
 gnm_float swap_log_tail (gnm_float lp);
 gnm_float pow1p (gnm_float x, gnm_float y);
 gnm_float pow1pm1 (gnm_float x, gnm_float y);
@@ -35,10 +38,11 @@ gnm_float gnm_trunc (gnm_float x);
 gnm_float logspace_add (gnm_float logx, gnm_float logy);
 gnm_float logspace_sub (gnm_float logx, gnm_float logy);
 gnm_float gnm_owent (gnm_float h, gnm_float a);
-gnm_float gnm_logcf (gnm_float x, gnm_float i, gnm_float d);
+gnm_float gnm_logcf (gnm_float x, gnm_float i, gnm_float d, gnm_float tol);
 gnm_float expmx2h (gnm_float x);
 gnm_float gnm_agm(gnm_float a, gnm_float b);
 gnm_float gnm_lambert_w(gnm_float x, int k);
+gnm_float gnm_ilog (gnm_float x, gnm_float b);
 
 /* "d": density.  */
 /* "p": distribution function.  */
