@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_RENDERED_VALUE_H_
 # define _GNM_RENDERED_VALUE_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <pango/pango.h>
 
 G_BEGIN_DECLS
@@ -42,12 +41,10 @@ struct _GnmRenderedRotatedValue {
 
 GnmRenderedValue *gnm_rendered_value_new       (GnmCell const *cell,
 						PangoContext *context,
-						gboolean variable_width,
+						gboolean allow_variable_width,
 						double zoom);
 void              gnm_rendered_value_destroy   (GnmRenderedValue *rv);
 
-GnmRenderedValue *gnm_rendered_value_recontext (GnmRenderedValue *rv,
-						PangoContext *context);
 void              gnm_rendered_value_remeasure (GnmRenderedValue *rv);
 
 /* Return the value as a single string without format infomation.  */
