@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_OBJECT_IMAGE_H_
 # define _GNM_SHEET_OBJECT_IMAGE_H_
 
-#include "sheet-object.h"
+#include <sheet-object.h>
 
 G_BEGIN_DECLS
 
@@ -15,9 +14,8 @@ typedef struct _SheetObjectImage SheetObjectImage;
 GType	     sheet_object_image_get_type (void);
 void sheet_object_image_set_image (SheetObjectImage *soi,
 				   char const   *type,
-				   guint8       *data,
-				   unsigned	 data_len,
-				   gboolean      copy_data);
+				   gconstpointer data,
+				   unsigned	 data_len);
 void sheet_object_image_set_crop (SheetObjectImage *soi,
 				  double crop_left,  double crop_top,
 				  double crop_right, double crop_bottom);
