@@ -222,7 +222,7 @@ sheet_style_find (Sheet const *sheet, GnmStyle *s)
 	return s;
 }
 
-/* Place holder until I merge in the new styles too */
+/* Placeholder until I merge in the new styles too */
 static void
 pstyle_set_border (GnmStyle *st, GnmBorder *border,
 		   GnmStyleBorderLocation side)
@@ -823,7 +823,7 @@ sheet_style_set_auto_pattern_color (Sheet *sheet, GnmColor *pattern_color)
 
 /**
  * sheet_style_get_auto_pattern_color:
- * @sheet: the sheet
+ * @sheet: The sheet
  *
  * Returns: (transfer full): the color for rendering auto colored patterns
  * in this sheet.
@@ -1289,7 +1289,7 @@ sheet_style_set_range (Sheet *sheet, GnmRange const *range,
 /**
  * sheet_style_apply_col:
  * @sheet: #Sheet being changed
- * @col: Column
+ * @col: Column number
  * @style: (transfer full): #GnmStyle
  *
  * NOTE: This is a simple wrapper for now.  When we support col/row styles it
@@ -1307,8 +1307,8 @@ sheet_style_apply_col (Sheet *sheet, int col, GnmStyle *pstyle)
 
 /**
  * sheet_style_apply_row:
- * @sheet:
- * @row:
+ * @sheet: #Sheet being changed
+ * @row: Row number
  * @style: (transfer full): #GnmStyle
  *
  * NOTE: This is a simple wrapper for now.  When we support col/row styles it
@@ -1326,9 +1326,9 @@ sheet_style_apply_row (Sheet  *sheet, int row, GnmStyle *pstyle)
 
 /**
  * sheet_style_apply_pos:
- * @sheet:
- * @col:
- * @row:
+ * @sheet: #Sheet being changed
+ * @col: Column number
+ * @row: Row number
  * @style: (transfer full): #GnmStyle
  *
  * Apply a partial style to a single cell
@@ -1346,9 +1346,9 @@ sheet_style_apply_pos (Sheet *sheet, int col, int row, GnmStyle *pstyle)
 }
 /**
  * sheet_style_set_pos:
- * @sheet:
- * @col:
- * @row:
+ * @sheet: #Sheet being changed
+ * @col: Column number
+ * @row: Row number
  * @style: (transfer full):
  *
  * Change the complete style for a single cell.
@@ -1368,7 +1368,7 @@ sheet_style_set_pos (Sheet *sheet, int col, int row,
 
 /**
  * sheet_style_default:
- * @sheet:
+ * @sheet: #Sheet
  *
  * Returns: (transfer full): default style for the sheet.
  **/
@@ -1385,7 +1385,7 @@ sheet_style_default (Sheet const *sheet)
 /**
  * sheet_style_get:
  * @sheet: #Sheet
- * @col: column number
+ * @col: Column number
  * @row: row number
  *
  * Returns: (transfer none): find the fully qualified style applicable to
@@ -2145,10 +2145,10 @@ cb_style_extent (GnmStyle *style,
 /**
  * sheet_style_get_extent:
  * @sheet: sheet to measure
- * @r: starting range and resulting range
+ * @r: (inout): starting range and resulting range
  *
- * A simple implementation that finds the smallest range containing all visible styles
- * and containing @res.
+ * A simple implementation that finds the smallest range containing
+ * all visible styles and containing @r.
  */
 void
 sheet_style_get_extent (Sheet const *sheet, GnmRange *res)
@@ -2161,7 +2161,7 @@ sheet_style_get_extent (Sheet const *sheet, GnmRange *res)
 
 struct cb_nondefault_extent {
 	GnmRange *res;
-	GnmStyle **col_defaults;
+	GPtrArray *col_defaults;
 };
 
 static void
@@ -2177,7 +2177,7 @@ cb_nondefault_extent (GnmStyle *style,
 		int col = corner_col + i;
 		if (col >= apply_to->start.col &&
 		    col <= apply_to->end.col &&
-		    style != user->col_defaults[col]) {
+		    style != g_ptr_array_index (user->col_defaults, col)) {
 			int max_row = MIN (corner_row + height - 1,
 					   apply_to->end.row);
 			int min_row = MAX (corner_row, apply_to->start.row);
@@ -2191,9 +2191,18 @@ cb_nondefault_extent (GnmStyle *style,
 	}
 }
 
+/**
+ * sheet_style_get_nondefault_extent:
+ * @sheet: sheet to inspect
+ * @extent: (inout): extent
+ * @src: range to inspect
+ * @col_defaults: (transfer none) (element-type GnmStyle): defaults styles
+ *
+ * Extends @extent so that it covers any non-default style used.
+ */
 void
 sheet_style_get_nondefault_extent (Sheet const *sheet, GnmRange *extent,
-				   const GnmRange *src, GnmStyle **col_defaults)
+				   const GnmRange *src, GPtrArray *col_defaults)
 {
 	struct cb_nondefault_extent user;
 	user.res = extent;
@@ -2203,7 +2212,7 @@ sheet_style_get_nondefault_extent (Sheet const *sheet, GnmRange *extent,
 
 struct cb_is_default {
 	gboolean res;
-	GnmStyle **col_defaults;
+	GPtrArray *col_defaults;
 };
 
 static void
@@ -2219,13 +2228,22 @@ cb_is_default (GnmStyle *style,
 	width = MIN (width, apply_to->end.col - corner_col + 1);
 
 	for (i = 0; user->res && i < width; i++) {
-		if (style != user->col_defaults[corner_col + i])
+		if (style != g_ptr_array_index (user->col_defaults, corner_col + i))
 			user->res = FALSE;
 	}
 }
 
+/**
+ * sheet_style_is_default:
+ * @sheet: sheet to inspect
+ * @r: range to inspect
+ * @col_defaults: (transfer none) (element-type GnmStyle): defaults styles
+ *
+ * Returns: %TRUE if all styles in the given range are default column styles.
+ */
 gboolean
-sheet_style_is_default (Sheet const *sheet, const GnmRange *r, GnmStyle **col_defaults)
+sheet_style_is_default (Sheet const *sheet, const GnmRange *r,
+			GPtrArray *col_defaults)
 {
 	struct cb_is_default user;
 
@@ -2238,8 +2256,8 @@ sheet_style_is_default (Sheet const *sheet, const GnmRange *r, GnmStyle **col_de
 }
 
 struct cb_get_nondefault {
-	guint8 *res;
-	GnmStyle **col_defaults;
+	GByteArray *res;
+	GPtrArray *col_defaults;
 };
 
 static void
@@ -2256,24 +2274,34 @@ cb_get_nondefault (GnmStyle *style,
 	height = MIN (height, apply_to->end.row - corner_row + 1);
 
 	for (i = 0; i < width; i++) {
-		if (style != user->col_defaults[corner_col + i]) {
+		if (style != g_ptr_array_index (user->col_defaults, corner_col + i)) {
 			int j;
 			for (j = 0; j < height; j++)
-				user->res[corner_row + j] = 1;
+				user->res->data[corner_row + j] = 1;
 			break;
 		}
 	}
 }
 
-guint8 *
-sheet_style_get_nondefault_rows (Sheet const *sheet, GnmStyle **col_defaults)
+/**
+ * sheet_style_get_nondefault_rows:
+ * @sheet: sheet to inspect
+ * @col_defaults: (transfer none) (element-type GnmStyle): defaults styles
+ *
+ * Returns: (transfer full): GByteArray with one element per row.  An
+ * element is %TRUE if the row uses a non-default style.
+ */
+GByteArray *
+sheet_style_get_nondefault_rows (Sheet const *sheet, GPtrArray *col_defaults)
 {
 	struct cb_get_nondefault user;
 	GnmRange r;
 
 	range_init_full_sheet (&r, sheet);
 
-	user.res = g_new0 (guint8, gnm_sheet_get_max_rows (sheet));
+	user.res = g_byte_array_new ();
+	g_byte_array_set_size (user.res, gnm_sheet_get_max_rows (sheet));
+	memset (user.res->data, 0, user.res->len);
 	user.col_defaults = col_defaults;
 
 	foreach_tile (sheet, &r, cb_get_nondefault, &user);
@@ -2315,18 +2343,19 @@ cb_most_common (GnmStyle *style,
 /**
  * sheet_style_most_common:
  * @sheet: sheet to inspect
- * @is_col: if %TRUE, look for common styles in columns; if FALSE, look in rows.
+ * @is_col: if %TRUE, look for common styles in columns; if %FALSE, look in
+ * rows.
  *
- * Returns: an array of styles describing the most common styles, one per column
- * or row.
+ * Returns: (transfer full) (element-type GnmStyle): an array of
+ * styles describing the most common styles, one per column or row.
  */
-GnmStyle **
+GPtrArray *
 sheet_style_most_common (Sheet const *sheet, gboolean is_col)
 {
 	GnmRange r;
 	struct cb_most_common cmc;
 	int *max;
-	GnmStyle **res;
+	GPtrArray *res;
 	GHashTableIter iter;
 	gpointer key, value;
 
@@ -2339,7 +2368,8 @@ sheet_style_most_common (Sheet const *sheet, gboolean is_col)
 	foreach_tile (sheet, &r, cb_most_common, &cmc);
 
 	max = g_new0 (int, cmc.l);
-	res = g_new0 (GnmStyle *, cmc.l);
+	res = g_ptr_array_new_with_free_func ((GDestroyNotify)gnm_style_unref);
+	g_ptr_array_set_size (res, cmc.l);
 	g_hash_table_iter_init (&iter, cmc.h);
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		int *counts = value;
@@ -2351,13 +2381,15 @@ sheet_style_most_common (Sheet const *sheet, gboolean is_col)
 			   order.  */
 			if (counts[j] > max[j]) {
 				max[j] = counts[j];
-				res[j] = style;
+				g_ptr_array_index (res, j) = style;
 			}
 		}
 	}
 	g_hash_table_destroy (cmc.h);
 	g_free (max);
 
+	g_ptr_array_foreach (res, (GFunc)gnm_style_ref, NULL);
+
 	return res;
 }
 
@@ -2838,12 +2870,12 @@ internal_style_list (Sheet const *sheet, GnmRange const *r,
 
 /**
  * sheet_style_get_range:
- * @sheet: the sheet in which to find styles
- * @r:     optional range to scan
+ * @sheet: #Sheet in which to find styles
+ * @r: (nullable): Range to scan
  *
  * Get a list of rectangles and their associated styles.
- * Caller is responsible for freeing.  Note that when a range is given,
- * the resulting ranges are relative to the input range.
+ * Note that when a range is given, the resulting ranges are relative
+ * to the input range.
  *
  * Returns: (transfer full):
  */
@@ -2869,11 +2901,12 @@ style_conditions_filter (GnmStyle const *style)
 
 /**
  * sheet_style_collect_conditions:
- * @sheet:
- * @r:
+ * @sheet: #Sheet
+ * @r: (nullable): Range to scan
  *
- * Returns: (transfer full): a list of areas with conditionals, Caller is
- * responsible for freeing.
+ * Returns: (transfer full): a list of areas with conditionals.
+ * Note that when a range is given, the resulting ranges are relative
+ * to the input range.
  **/
 GnmStyleList *
 sheet_style_collect_conditions (Sheet const *sheet, GnmRange const *r)
@@ -2898,11 +2931,12 @@ style_hlink_filter (GnmStyle const *style)
 
 /**
  * sheet_style_collect_hlinks:
- * @sheet:
- * @r:
+ * @sheet: #Sheet
+ * @r: (nullable): Range to scan
  *
- * Returns: (transfer full): a list of areas with hyperlinks, Caller is
- * responsible for freeing.
+ * Returns: (transfer full): a list of areas with hyperlinks.
+ * Note that when a range is given, the resulting ranges are relative
+ * to the input range.
  **/
 GnmStyleList *
 sheet_style_collect_hlinks (Sheet const *sheet, GnmRange const *r)
@@ -2930,10 +2964,12 @@ style_validation_filter (GnmStyle const *style)
 /**
  * sheet_style_collect_validations:
  * @sheet: the to trawl
- * @r: (allow-none): range to restrict to
+ * @r: (nullable): Range to scan
  *
  * Returns: (transfer full): a list of areas with validation or input
  * message.
+ * Note that when a range is given, the resulting ranges are relative
+ * to the input range.
  **/
 GnmStyleList *
 sheet_style_collect_validations (Sheet const *sheet, GnmRange const *r)
@@ -2983,7 +3019,7 @@ sheet_style_set_list (Sheet *sheet, GnmCellPos const *corner,
 
 /**
  * style_list_free:
- * @l: the list to free
+ * @l: (transfer full): the list to free
  *
  * Free up the resources in the style list.  This includes unreferencing the
  * styles.
@@ -2997,12 +3033,13 @@ style_list_free (GnmStyleList *list)
 /**
  * style_list_get_style:
  * @l: A style list.
- * @col:
- * @row:
+ * @col: Column number
+ * @row: Row number
  *
  * Attempts to find the style associated with the @pos offset within the 0,0
  * based style list.
- * The resulting style does not have its reference count bumped.
+ *
+ * Returns: (transfer none) (nullable): The style found.
  **/
 GnmStyle const *
 style_list_get_style (GnmStyleList const *list, int col, int row)
@@ -3031,13 +3068,13 @@ cb_find_link (GnmStyle *style,
 
 /**
  * sheet_style_region_contains_link:
- * @sheet:
- * @r:
+ * @sheet: #Sheet
+ * @r: #GnmRange to search for links
  *
- * Utility routine that checks to see if a region contains at least 1 hyper link
- * and returns the 1st one it finds.
+ * Utility routine that checks to see if a region contains at least ones
+ * hyperlink and returns the first one it finds.
  *
- * Returns: (transfer none): the found #GmHLink if any.
+ * Returns: (transfer none) (nullable): the found #GmHLink if any.
  **/
 GnmHLink *
 sheet_style_region_contains_link (Sheet const *sheet, GnmRange const *r)
@@ -3076,7 +3113,7 @@ sheet_style_foreach (Sheet const *sheet, GFunc func, gpointer user_data)
 /**
  * sheet_style_range_foreach:
  * @sheet: #Sheet
- * @r: optional range
+ * @r: (nullable): range
  * @func: (scope call): callback.
  * @user_data: user data
  *
