@@ -1,11 +1,10 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * analysis-signed-rank-test.c:
  *
  * Author:
  *   Andreas J. Guelzow  <aguelzow@pyrshep.ca>
  *
- * (C) Copyright 2010 by Andreas J. Guelzow  <aguelzow@pyrshep.ca>
+ * (C) Copyright 2010, 2016 by Andreas J. Guelzow  <aguelzow@pyrshep.ca>
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,20 +18,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "analysis-signed-rank-test.h"
-#include "analysis-tools.h"
-#include "value.h"
-#include "ranges.h"
-#include "expr.h"
-#include "func.h"
-#include "numbers.h"
+#include <gnumeric.h>
+#include <tools/analysis-signed-rank-test.h>
+#include <tools/analysis-tools.h>
+#include <value.h>
+#include <ranges.h>
+#include <expr.h>
+#include <func.h>
+#include <numbers.h>
 
 static inline GnmExpr const *
 make_int (int n)
@@ -240,17 +238,17 @@ analysis_tool_signed_rank_test_engine_run (data_analysis_output_t *dao,
 		dao_set_cell_expr (dao, col + 1, 9, expr);
 	}
 
-	gnm_func_unref (fd_median);
-	gnm_func_unref (fd_if);
-	gnm_func_unref (fd_min);
-	gnm_func_unref (fd_sum);
-	gnm_func_unref (fd_normdist);
-	gnm_func_unref (fd_isnumber);
-	gnm_func_unref (fd_iferror);
-	gnm_func_unref (fd_rank);
-	gnm_func_unref (fd_abs);
-	gnm_func_unref (fd_sqrt);
-	gnm_func_unref (fd_max);
+	gnm_func_dec_usage (fd_median);
+	gnm_func_dec_usage (fd_if);
+	gnm_func_dec_usage (fd_min);
+	gnm_func_dec_usage (fd_sum);
+	gnm_func_dec_usage (fd_normdist);
+	gnm_func_dec_usage (fd_isnumber);
+	gnm_func_dec_usage (fd_iferror);
+	gnm_func_dec_usage (fd_rank);
+	gnm_func_dec_usage (fd_abs);
+	gnm_func_dec_usage (fd_sqrt);
+	gnm_func_dec_usage (fd_max);
 
 	dao_redraw_respan (dao);
 
@@ -381,7 +379,7 @@ analysis_tool_signed_rank_test_two_engine_run (data_analysis_output_t *dao,
 		   (fd_iferror, gnm_expr_new_funcall3
 		    (fd_if, gnm_expr_new_binary
 		     (gnm_expr_copy (expr_diff),
-		      GNM_EXPR_OP_NOT_EQUAL, make_cellref (0,-2)),
+		      GNM_EXPR_OP_NOT_EQUAL, make_cellref (0,-1)),
 		     make_int (1),
 		     make_int (0)),
 		    make_int (0))));
@@ -507,17 +505,17 @@ analysis_tool_signed_rank_test_two_engine_run (data_analysis_output_t *dao,
 				    GNM_EXPR_OP_MULT, make_cellref (0,-1));
 	dao_set_cell_array_expr (dao, 1, 10, expr);
 
-	gnm_func_unref (fd_median);
-	gnm_func_unref (fd_if);
-	gnm_func_unref (fd_min);
-	gnm_func_unref (fd_sum);
-	gnm_func_unref (fd_normdist);
-	gnm_func_unref (fd_isnumber);
-	gnm_func_unref (fd_iferror);
-	gnm_func_unref (fd_rank);
-	gnm_func_unref (fd_abs);
-	gnm_func_unref (fd_sqrt);
-	gnm_func_unref (fd_max);
+	gnm_func_dec_usage (fd_median);
+	gnm_func_dec_usage (fd_if);
+	gnm_func_dec_usage (fd_min);
+	gnm_func_dec_usage (fd_sum);
+	gnm_func_dec_usage (fd_normdist);
+	gnm_func_dec_usage (fd_isnumber);
+	gnm_func_dec_usage (fd_iferror);
+	gnm_func_dec_usage (fd_rank);
+	gnm_func_dec_usage (fd_abs);
+	gnm_func_dec_usage (fd_sqrt);
+	gnm_func_dec_usage (fd_max);
 
 	value_release (val_1);
 	value_release (val_2);
