@@ -1485,14 +1485,14 @@ cell_is_constant (GnmCell *cell, gnm_float *pc)
 	return gnm_finite (*pc);
 }
 
-#define SET_LOWER(l_)						\
-	do {							\
-		sol->min[idx] = MAX (sol->min[idx], (l_));	\
+#define SET_LOWER(l_)							\
+	do {								\
+		sol->min[idx] = MAX (sol->min[idx], (gnm_float)(l_));	\
 	} while (0)
 
-#define SET_UPPER(l_)						\
-	do {							\
-		sol->max[idx] = MIN (sol->max[idx], (l_));	\
+#define SET_UPPER(l_)							\
+	do {								\
+		sol->max[idx] = MIN (sol->max[idx], (gnm_float)(l_));	\
 	} while (0)
 
 
@@ -1615,7 +1615,7 @@ gnm_solver_update_derived (GnmSolver *sol)
 } while (0)
 
 #define AT_LIMIT(s_,l_) \
-  (gnm_finite (l_) ? gnm_abs ((s_) - (l_)) <= (gnm_abs ((s_)) + gnm_abs ((l_))) / 1e10 : (s_) == (l_))
+	(gnm_finite (l_) ? gnm_abs ((s_) - (l_)) <= (gnm_abs ((s_)) + gnm_abs ((l_))) / GNM_const(1e10) : (s_) == (l_))
 
 #define MARK_BAD(col_)						\
   do {								\
@@ -1795,7 +1795,7 @@ gnm_solver_create_program_report (GnmSolver *solver, const char *name)
 				break;
 			}
 			case GNM_SOLVER_BOOLEAN: {
-				gnm_float c = (cl > 0.5 ? 1 : 0);
+				gnm_float c = (cl > GNM_const(0.5) ? 1 : 0);
 				slack = 0 - gnm_abs (c - cl);
 				break;
 			}
@@ -2152,7 +2152,7 @@ gnm_solver_compute_gradient (GnmSolver *sol, gnm_float const *xs)
 		 * error except, potentially, a single step that crosses an
 		 * integer power of 2.
 		 */
-		dx = 16 * (go_add_epsilon (x0) - x0);
+		dx = 16 * (gnm_add_epsilon (x0) - x0);
 		dy = 0;
 		for (j = -order; j <= order; j++) {
 			gnm_float y;
@@ -2551,7 +2551,9 @@ gnm_solver_get_lp_coeffs (GnmSolver *sol, GnmCell *ycell,
 			if (!gnm_finite (y01))
 				goto fail_calc;
 
-			emax = dy == 0 ? 1e-10 : gnm_abs (dy) / 1e-10;
+			emax = dy == 0
+				? GNM_const(1e-10)
+				: gnm_abs (dy) / GNM_const(1e-10);  // ????
 			e = dy - 2 * (y01 - y0);
 			if (gnm_abs (e) > emax)
 				goto fail_linear;
