@@ -1,11 +1,10 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_VALUE_H_
 # define _GNM_VALUE_H_
 
-#include "gnumeric.h"
-#include "position.h"
-#include "numbers.h"
-#include "parse-util.h"
+#include <gnumeric.h>
+#include <position.h>
+#include <numbers.h>
+#include <parse-util.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -149,7 +148,9 @@ char const *value_peek_string	   (GnmValue const *v);
 char       *value_get_as_string	   (GnmValue const *v);
 void        value_get_as_gstring   (GnmValue const *v, GString *target,
 				    GnmConventions const *conv);
+char       *value_stringify        (GnmValue const *v);
 
+GnmValueType value_type_of         (GnmValue const *v);
 int         value_get_as_int	   (GnmValue const *v);
 gnm_float   value_get_as_float	   (GnmValue const *v);
 gboolean    value_is_zero	   (GnmValue const *v);
@@ -191,38 +192,6 @@ extern GnmValueErr const value_terminate_err;
 
 void value_array_set       (GnmValue *array, int col, int row, GnmValue *v);
 
-typedef struct _GnmCriteria GnmCriteria;
-
-/* FIXME: this stuff below ought to go elsewhere.  */
-typedef gboolean (*GnmCriteriaFunc) (GnmValue const *x, GnmCriteria *crit);
-struct _GnmCriteria {
-        GnmCriteriaFunc fun;
-        GnmValue *x;
-        int column; /* absolute */
-	CellIterFlags iter_flags;
-	GODateConventions const *date_conv;
-	GORegexp rx;
-	gboolean has_rx;
-	unsigned ref_count; /* for boxed type */
-};
-GType   gnm_criteria_get_type (void);
-
-typedef struct {
-        int     row;	/* absolute */
-        GSList *conditions;
-} GnmDBCriteria;
-
-GnmCriteria *parse_criteria (GnmValue const *crit_val,
-			     GODateConventions const *date_conv);
-void	free_criteria		(GnmCriteria *criteria);
-void	free_criterias		(GSList *criterias);
-GSList *find_rows_that_match	(Sheet *sheet, int first_col,
-				 int first_row, int last_col, int last_row,
-				 GSList *criterias, gboolean unique_only);
-GSList *parse_database_criteria (GnmEvalPos const *ep,
-				 GnmValue const *database, GnmValue const *criteria);
-int     find_column_of_field	(GnmEvalPos const *ep,
-				 GnmValue const *database, GnmValue const *field);
 
 /* Protected */
 void value_init     (void);
