@@ -3,6 +3,7 @@
  *			like wrappers in libgsf
  *
  * Copyright (C) 2003-2007 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2024 Morten Welinder <terra@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1024,9 +1025,11 @@ xml_write_filter_field (GnmOutputXML *state,
 	case GNM_FILTER_OP_TOP_N:
 		gsf_xml_out_add_cstr_unchecked (state->output, "Type", "bucket");
 		gsf_xml_out_add_bool (state->output, "top",
-			cond->op[0] & 1 ? TRUE : FALSE);
+				      !(cond->op[0] & GNM_FILTER_OP_BOTTOM_MASK));
 		gsf_xml_out_add_bool (state->output, "items",
-			cond->op[0] & 2 ? TRUE : FALSE);
+				      !(cond->op[0] & GNM_FILTER_OP_PERCENT_MASK));
+		gsf_xml_out_add_bool (state->output, "rel_range",
+				      !(cond->op[0] & GNM_FILTER_OP_REL_N_MASK));
 		go_xml_out_add_double (state->output, "count", cond->count);
 		break;
 	}
@@ -1442,7 +1445,7 @@ xml_write_number_system (GnmOutputXML *state)
 	 * number system of the loading Gnumeric is different from the
 	 * number system of the saving Gnumeric.
 	 */
-	gsf_xml_out_add_int (state->output, "FloatRadix", FLT_RADIX);
+	gsf_xml_out_add_int (state->output, "FloatRadix", GNM_RADIX);
 	gsf_xml_out_add_int (state->output, "FloatDigits", GNM_MANT_DIG);
 }
 
@@ -1457,7 +1460,7 @@ xml_write_calculation (GnmOutputXML *state)
 		"EnableIteration",	state->wb->iteration.enabled);
 	gsf_xml_out_add_int (state->output,
 		"MaxIterations",	state->wb->iteration.max_number);
-	go_xml_out_add_double (state->output,
+	gnm_xml_out_add_gnm_float (state->output,
 		"IterationTolerance",	state->wb->iteration.tolerance);
 	xml_write_date_conventions_as_attr (state,
 					    workbook_date_conv (state->wb));
@@ -1481,7 +1484,7 @@ gnm_xml_io_conventions (void)
 	res->output.uppercase_E = FALSE;
 
 	if (!gnm_shortest_rep_in_files ()) {
-		gnm_float l10 = gnm_log10 (FLT_RADIX);
+		gnm_float l10 = gnm_log10 (GNM_RADIX);
 		res->output.decimal_digits =
 			(int)gnm_ceil (GNM_MANT_DIG * l10) +
 			(l10 == (int)l10 ? 0 : 1);
