@@ -25,6 +25,16 @@ if (&subtest ("ods")) {
 		     'ignore_failure' => 1);
 }
 
+if (&subtest ("ods-strict")) {
+    &message ("Check string ods strict-conformance roundtrip.");
+    &test_roundtrip ($file,
+		     'format' => 'Gnumeric_OpenCalc:openoffice',
+		     'ext' => "ods",
+		     'filter1' => 'std:ods_strict',
+		     'filter2' => 'std:drop_generator | std:ods_strict',
+		     'ignore_failure' => 1);
+}
+
 if (&subtest ("biff7")) {
     # We don't save graphs, so don't test.
     &message ("Check graph xls/BIFF7 roundtrip.");
